@@ -1,4 +1,5 @@
-from .utils import Utils
+from .utils import SettingsReader
+from .utils import SettingsReader as Utils  ##alias for backward compatibility
 from .filemanager import FileManager
 from .appsettings import AppSettings
 from .modelbase import ModelCommonParent
