@@ -121,7 +121,7 @@ class Exporter(object):
         if PY2:
             self.retfile = tempfile.NamedTemporaryFile()
         else:
-            self.retfile = tempfile.NamedTemporaryFile(mode='w')
+            self.retfile = tempfile.NamedTemporaryFile(mode='w',encoding="utf8")
 
 
     def writeAll(self, delimiter = None):
@@ -150,7 +150,7 @@ class Importer(object):
         if PY2:
             self.csvreader = UnicodeReader(open(fn,'rb'),delimiter=delimiter)
         else:
-            self.csvreader = csv.reader(open(fn,'r'), dialect=csv.excel,delimiter=delimiter)
+            self.csvreader = csv.reader(open(fn,'r',encoding='utf-8'), dialect=csv.excel,delimiter=delimiter)
         #self.csvreader = csv.reader(f,delimiter=";")
         
         h = next(self.csvreader)
