@@ -16,9 +16,10 @@ else:
         if isinstance(v, str):
             return False
         return hasattr(v, '__iter__')
+string = types.StringTypes if PY2 else str
 
 
-class Utils():
+class SettingsReader():
     myconf = []
 
     @classmethod
@@ -30,7 +31,7 @@ class Utils():
     def __getMyConf(cls,settings, prefix,defaultval=None,**kwargs):
         resvals = {}
         resdicts = {}
-        string = types.StringTypes if PY2 else str
+        #string = types.StringTypes if PY2 else str
         l.debug("reading conf for {}".format(prefix))
         for k in cls.myconf:
             if isinstance(k, string):
@@ -66,7 +67,11 @@ class Utils():
             setattr(cls, key, value)
             l.debug("value of {key} set to: {val}".format(key=key, val=value))
             #setattr(cls,k,unicode(settings[key]) )
-        for key in cls.myconf:
+        for k in cls.myconf:
+            if isinstance(k, string):
+                key = k
+            else:
+                key = k[0]
             l.debug("val for {key} = {val}".format(
                 key=key, val=getattr(cls, key)))
         return resvals
@@ -84,6 +89,7 @@ class Utils():
             if key in parse:
                 value = parse[key](value)
             resdicts[key]=value
+            cls.myconf.append(key)
         for key, value in resdicts.items():
             setattr(cls, key, value)
             resvals[key]=value
@@ -111,8 +117,24 @@ class Utils():
             prefix = cls.__name__.lower()
 
         if cls.myconf:
-            return cls.__getMyConf(settings ,prefix,defaultval  )
+            cls.__getMyConf(settings ,prefix,defaultval  )
         else:
             cls.__getAllConf(settings ,prefix,defaultval  )
 
         cls.confended()
+
+
+    @classmethod
+    def conf2dict(cls):
+        valdict = {}
+        for k in cls.myconf:
+            if isinstance(k, string):
+                prop = k
+            else:
+                prop = k[0]
+            try:
+                valdict[prop] = getattr(cls,prop)
+            except Exception as e:
+                l.exception(f"{prop} configured as a key, but no value found")
+        return valdict
+
